Struct RtcpHeader

pub struct RtcpHeader {
    pub version: u2,
    pub has_padding: bool,
    pub report_count: u5,
    pub packet_type: u8,
    pub length_field: u16,
}
https://datatracker.ietf.org/doc/html/rfc3550#section-6.1 0 1 2 3 0 1 2 3 4 5 6 7 8 9 0 1 2 3 4 5 6 7 8 9 0 1 2 3 4 5 6 7 8 9 0 1 +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+ |V=2|P| SC | PT=SDES=202 | length | +=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+

length: 16 bits The length of this RTCP packet in 32-bit words minus one, including the header and any padding. (The offset of one makes zero a valid length and avoids a possible infinite loop in scanning a compound RTCP packet, while counting 32-bit words avoids a validity check for a multiple of 4.)

Fields

version: u2has_padding: boolreport_count: u5packet_type: u8length_field: u16

Implementations

Source

impl RtcpHeader

pub const SIZE_BYTES: usize = 4usize

pub fn payload_length_bytes(&self) -> Result<u16>

The length of this RTCP packet’s payload (i.e. excluding the header) in bytes