pub fn read_two_byte_header_extension(buf: &mut Bytes) -> TwoByteHeaderExtensionExpand description
[buf] should start at the beginning of the header extension (the id)
pub fn read_two_byte_header_extension(buf: &mut Bytes) -> TwoByteHeaderExtension[buf] should start at the beginning of the header extension (the id)