pub struct RtpHeader;Expand description
- https://tools.ietf.org/html/rfc3550#section-5.1 0 1 2 3 0 1 2 3 4 5 6 7 8 9 0 1 2 3 4 5 6 7 8 9 0 1 2 3 4 5 6 7 8 9 0 1 +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+ |V=2|P|X| CC |M| PT | sequence number | +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+ | timestamp | +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+ | synchronization source (SSRC) identifier | +=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+=+ | contributing source (CSRC) identifiers | | …. | +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+ | …extensions (if present)… | +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
Implementations
Sourceimpl RtpHeader
impl RtpHeader
pub fn version(buf: &[u8]) -> u2
pub fn has_padding(buf: &[u8]) -> bool
pub fn has_extensions(buf: &[u8]) -> bool
pub fn csrc_count(buf: &[u8]) -> u4
pub fn marked(buf: &[u8]) -> bool
pub fn payload_type(buf: &[u8]) -> u7
pub fn seq_num(buf: &[u8]) -> u16
pub fn timestamp(buf: &[u8]) -> u32
pub fn ssrc(buf: &[u8]) -> u32
Sourcepub fn extensions_start_offset(buf: &[u8]) -> usize
pub fn extensions_start_offset(buf: &[u8]) -> usize
Returns the offset into the given buffer where the top-level extensions header would start, if this packet contains extensions.
pub fn payload_offset(buf: &[u8]) -> usize
Sourcepub fn header_extensions_length_bytes(buf: &[u8]) -> u16
pub fn header_extensions_length_bytes(buf: &[u8]) -> u16
Returns the length of the extensions (including the extensions header) in bytes. If has_extensions is false, returns 0.